<?php
/*******************************************************************************

    Author ......... Jimmy Conner
    Contact ........ jimmy@advcs.org
    Home Site ...... http://www.advcs.org/
    Program ........ Block Attachments
    Version ........ 0.4
    Purpose ........ Allows an admin to block any types of attachments

*******************************************************************************/

   if (!defined('SM_PATH'))
      define('SM_PATH','../../');

   function squirrelmail_plugin_init_block_attach() {
      include_once(SM_PATH . 'plugins/block_attach/includes/hooks.php');
   }

   function block_attach_block (&$Args) {
      include(SM_PATH . 'plugins/block_attach/includes/block_function.php');
   }

   function block_attach_display_option() {
      include_once(SM_PATH . 'plugins/block_attach/includes/display_options.php');
   }

   function block_attach_version() {
      return '0.4';
   }

?>